#[non_exhaustive]pub struct CertEntry {
pub fingerprint: CertFingerprint,
pub cert_type: CertType,
}Expand description
One entry in a status token’s certificate fingerprint array.
Each status token contains arrays of valid server and identity certificates. During verification, the presented certificate must match at least one entry.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fingerprint: CertFingerprintCertificate fingerprint in SHA256:<hex> format.
cert_type: CertTypeCertificate type.
Implementations